==> runtime-tools-quarkus-extension-deployment-1.41.0.Final.jar: dev-static/webapp/envelope/RuntimeToolsDevUIEnvelopeApiImpl.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuntimeToolsDevUIEnvelopeApiImpl = void 0;
var RuntimeToolsDevUIEnvelopeApiImpl = (function () {
    function RuntimeToolsDevUIEnvelopeApiImpl(args) {
        var _this = this;
        this.args = args;
        this.capturedInitRequestYet = false;
        this.runtimeToolsDevUI_initRequest = function (association, initArgs) { return __awaiter(_this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                this.args.envelopeBusController.associate(association.origin, association.envelopeServerId);
                if (this.hasCapturedInitRequestYet()) {
                    return [2];
                }
                this.ackCapturedInitRequest();
                this.args.view().setDataIndexUrl(initArgs.dataIndexUrl);
                this.args.view().setTrustyServiceUrl(initArgs.trustyServiceUrl);
                this.args.view().setUsers(initArgs.users);
                this.args.view().navigateTo(initArgs.page);
                this.args.view().setDevUIUrl &&
                    this.args.view().setDevUIUrl(initArgs.devUIUrl);
                this.args.view().setOpenApiPath &&
                    this.args.view().setOpenApiPath(initArgs.openApiPath);
                this.args.view().setAvailablePages &&
                    this.args.view().setAvailablePages(initArgs.availablePages);
                this.args.view().setCustomLabels &&
                    this.args.view().setCustomLabels(initArgs.customLabels);
                this.args.view().setOmittedProcessTimelineEvents &&
                    this.args
                        .view()
                        .setOmittedProcessTimelineEvents(initArgs.omittedProcessTimelineEvents);
                this.args.view().setDiagramPreviewSize &&
                    this.args.view().setDiagramPreviewSize(initArgs.diagramPreviewSize);
                this.args.view().setIsStunnerEnabled &&
                    this.args.view().setIsStunnerEnabled(initArgs.isStunnerEnabled);
                this.args.view().setProcessEnabled(initArgs.isDataIndexAvailable);
                this.args.view().setTracingEnabled(initArgs.isTracingEnabled);
                return [2];
            });
        }); };
    }
    RuntimeToolsDevUIEnvelopeApiImpl.prototype.hasCapturedInitRequestYet = function () {
        return this.capturedInitRequestYet;
    };
    RuntimeToolsDevUIEnvelopeApiImpl.prototype.ackCapturedInitRequest = function () {
        this.capturedInitRequestYet = true;
    };
    return RuntimeToolsDevUIEnvelopeApiImpl;
}());
exports.RuntimeToolsDevUIEnvelopeApiImpl = RuntimeToolsDevUIEnvelopeApiImpl;
//# sourceMappingURL=RuntimeToolsDevUIEnvelopeApiImpl.js.map

==> runtime-tools-quarkus-extension-deployment-1.44.1.Final.jar: dev-static/webapp/envelope/RuntimeToolsDevUIEnvelopeApiImpl.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuntimeToolsDevUIEnvelopeApiImpl = void 0;
var RuntimeToolsDevUIEnvelopeApiImpl = (function () {
    function RuntimeToolsDevUIEnvelopeApiImpl(args) {
        var _this = this;
        this.args = args;
        this.capturedInitRequestYet = false;
        this.runtimeToolsDevUI_initRequest = function (association, initArgs) { return __awaiter(_this, void 0, void 0, function () {
            var _a;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        if (this.hasCapturedInitRequestYet()) {
                            return [2];
                        }
                        this.args.envelopeClient.associate(association.origin, association.envelopeServerId);
                        this.ackCapturedInitRequest();
                        _a = this;
                        return [4, this.args.viewDelegate()];
                    case 1:
                        _a.view = _b.sent();
                        this.view().setDataIndexUrl(initArgs.dataIndexUrl);
                        this.view().setTrustyServiceUrl(initArgs.trustyServiceUrl);
                        this.view().setUsers(initArgs.users);
                        this.view().navigateTo(initArgs.page);
                        this.view().setDevUIUrl && this.view().setDevUIUrl(initArgs.devUIUrl);
                        this.view().setOpenApiPath &&
                            this.view().setOpenApiPath(initArgs.openApiPath);
                        this.view().setAvailablePages &&
                            this.view().setAvailablePages(initArgs.availablePages);
                        this.view().setCustomLabels &&
                            this.view().setCustomLabels(initArgs.customLabels);
                        this.view().setOmittedProcessTimelineEvents &&
                            this.view().setOmittedProcessTimelineEvents(initArgs.omittedProcessTimelineEvents);
                        this.view().setDiagramPreviewSize &&
                            this.view().setDiagramPreviewSize(initArgs.diagramPreviewSize);
                        this.view().setIsStunnerEnabled &&
                            this.view().setIsStunnerEnabled(initArgs.isStunnerEnabled);
                        this.view().setProcessEnabled(initArgs.isDataIndexAvailable);
                        this.view().setTracingEnabled(initArgs.isTracingEnabled);
                        return [2];
                }
            });
        }); };
    }
    RuntimeToolsDevUIEnvelopeApiImpl.prototype.hasCapturedInitRequestYet = function () {
        return this.capturedInitRequestYet;
    };
    RuntimeToolsDevUIEnvelopeApiImpl.prototype.ackCapturedInitRequest = function () {
        this.capturedInitRequestYet = true;
    };
    return RuntimeToolsDevUIEnvelopeApiImpl;
}());
exports.RuntimeToolsDevUIEnvelopeApiImpl = RuntimeToolsDevUIEnvelopeApiImpl;
//# sourceMappingURL=RuntimeToolsDevUIEnvelopeApiImpl.js.map
